# Copyright 2024 The AI Edge Quantizer Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================

"""Default quantization policy."""

from ai_edge_quantizer import qtyping

_TFLOpName = qtyping.TFLOperationName
_OpQuantizationConfig = qtyping.OpQuantizationConfig
_TensorQuantizationConfig = qtyping.TensorQuantizationConfig
_OpExecutionMode = qtyping.OpExecutionMode
_Granularity = qtyping.QuantGranularity
_INT = qtyping.TensorDataType.INT

DEFAULT_CONFIG_CHECK_POLICY = qtyping.ConfigCheckPolicyDict({
    _TFLOpName.FULLY_CONNECTED: [
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.BLOCKWISE,
                dtype=_INT,
                block_size=64,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.BLOCKWISE,
                dtype=_INT,
                block_size=64,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.BLOCKWISE,
                dtype=_INT,
                block_size=64,
            ),
            execution_mode=_OpExecutionMode.DRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.BLOCKWISE,
                dtype=_INT,
                block_size=64,
            ),
            execution_mode=_OpExecutionMode.DRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.DRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.DRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.DRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.DRQ,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
    ],
    _TFLOpName.CONV_2D: [
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.DRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.DRQ,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
    ],
    _TFLOpName.EMBEDDING_LOOKUP: [
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.DRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.DRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.DRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.DRQ,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
    ],
    _TFLOpName.AVERAGE_POOL_2D: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
    ],
    _TFLOpName.RESHAPE: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
    ],
    _TFLOpName.SOFTMAX: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
    ],
    _TFLOpName.DEPTHWISE_CONV_2D: [
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.DRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.DRQ,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
    ],
    _TFLOpName.TANH: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
    ],
    _TFLOpName.TRANSPOSE: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
    ],
    _TFLOpName.GELU: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
    ],
    _TFLOpName.ADD: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
    ],
    _TFLOpName.SUB: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
    ],
    _TFLOpName.MUL: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
    ],
    _TFLOpName.BATCH_MATMUL: [
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.DRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.DRQ,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
    ],
    _TFLOpName.MEAN: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
    ],
    _TFLOpName.RSQRT: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
    ],
    _TFLOpName.CONCATENATION: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
    ],
    _TFLOpName.STRIDED_SLICE: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
    ],
    _TFLOpName.SPLIT: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
    ],
    _TFLOpName.CONV_2D_TRANSPOSE: [
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.DRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.DRQ,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.WEIGHT_ONLY,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            execution_mode=_OpExecutionMode.SRQ,
        ),
    ],
})
